@@ -87,7 +87,7 @@ fn help(name: &str, opts: &Options) {
 /// Prints version information following the GNU Standards format.
 fn version() {
     println!("EndBASIC {}", env!("CARGO_PKG_VERSION"));
-    println!("Copyright 2020-2021 Julio Merino");
+    println!("Copyright 2020-2022 Julio Merino");
     println!("License Apache Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>");
 }
 
@@ -172,7 +172,7 @@ fn setup_console(console_spec: Option<&str>) -> io::Result<Rc<RefCell<dyn Consol
         Err(io::Error::new(io::ErrorKind::InvalidInput, "SDL support not compiled in"))
     }
 
-    let console: Rc<RefCell<dyn Console>> = match console_spec.as_deref() {
+    let console: Rc<RefCell<dyn Console>> = match console_spec {
         None | Some("text") => setup_text_console()?,
 
         Some("graphics") => setup_graphics_console("")?,
