@@ -191,14 +191,12 @@ fn test_cli_autoexec_is_ignored() {
 #[test]
 fn test_cli_help() {
     fn check_with_args(args: &[&str]) {
-        check(
-            &bin_path("endbasic"),
-            args,
-            0,
-            Behavior::Null,
-            Behavior::File(src_path("cli/tests/cli/help.out")),
-            Behavior::Null,
-        );
+        let exp_stdout = if cfg!(feature = "sdl") {
+            Behavior::File(src_path("cli/tests/cli/help.out.sdl"))
+        } else {
+            Behavior::File(src_path("cli/tests/cli/help.out"))
+        };
+        check(&bin_path("endbasic"), args, 0, Behavior::Null, exp_stdout, Behavior::Null);
     }
     check_with_args(&["-h"]);
     check_with_args(&["--help"]);
@@ -554,6 +552,30 @@ fn test_repl_exit_nonzero() {
     );
 }
 
+#[test]
+fn test_repl_exit_saved() {
+    check(
+        bin_path("endbasic"),
+        &["--local-drive=memory://"],
+        0,
+        Behavior::File(src_path("cli/tests/repl/exit-saved.in")),
+        Behavior::File(src_path("cli/tests/repl/exit-saved.out")),
+        Behavior::Null,
+    );
+}
+
+#[test]
+fn test_repl_exit_unsaved() {
+    check(
+        bin_path("endbasic"),
+        &["--local-drive=memory://"],
+        0,
+        Behavior::File(src_path("cli/tests/repl/exit-unsaved.in")),
+        Behavior::File(src_path("cli/tests/repl/exit-unsaved.out")),
+        Behavior::Null,
+    );
+}
+
 #[test]
 fn test_repl_exit_zero() {
     check(
